@@ -10,6 +10,7 @@ const app = createApp({
     const state = reactive({
       // options and selections
       tag: null, // picked tag
+      _tag: null, // display tag
       routeId: null, // picked route
       schemaId: null, // picked schema
       showFields: "object",
@@ -18,9 +19,12 @@ const app = createApp({
         { label: "Object fields", value: "object" },
         { label: "All fields", value: "all" },
       ],
+      enableBriefMode: false,
       brief: false,
+      focus: false,
       hidePrimitiveRoute: false,
       generating: false,
+      swaggerUrl: null,
       rawTags: [], // [{ name, routes: [{ id, name }] }]
       rawSchemas: new Set(), // [{ name, id }]
       rawSchemasFull: {}, // full schemas dict: { [schema.id]: schema }
@@ -28,6 +32,9 @@ const app = createApp({
       // Splitter size (left panel width in px)
       splitter: 300,
       detailDrawer: false,
+      drawerWidth: 300, // drawer 宽度
+      version: "", // version from backend
+      showModule: true,
     });
 
     const showDetail = ref(false);
@@ -43,6 +50,7 @@ const app = createApp({
     const schemaCodeName = ref("");
     const routeCodeId = ref("");
     const showRouteDetail = ref(false);
+    let graphUI = null;
 
     function openDetail() {
       showDetail.value = true;
@@ -51,6 +59,66 @@ const app = createApp({
       showDetail.value = false;
     }
 
+    function readQuerySelection() {
+      if (typeof window === "undefined") {
+        return { tag: null, route: null };
+      }
+      const params = new URLSearchParams(window.location.search);
+      return {
+        tag: params.get("tag") || null,
+        route: params.get("route") || null,
+      };
+    }
+
+    function findTagByRoute(routeId) {
+      return (
+        state.rawTags.find((tag) =>
+          (tag.routes || []).some((route) => route.id === routeId)
+        )?.name || null
+      );
+    }
+
+    function syncSelectionToUrl() {
+      if (typeof window === "undefined") {
+        return;
+      }
+      const params = new URLSearchParams(window.location.search);
+      if (state.tag) {
+        params.set("tag", state.tag);
+      } else {
+        params.delete("tag");
+      }
+      if (state.routeId) {
+        params.set("route", state.routeId);
+      } else {
+        params.delete("route");
+      }
+      const hash = window.location.hash || "";
+      const search = params.toString();
+      const base = window.location.pathname;
+      const newUrl = search ? `${base}?${search}${hash}` : `${base}${hash}`;
+      window.history.replaceState({}, "", newUrl);
+    }
+
+    function applySelectionFromQuery(selection) {
+      let applied = false;
+      if (selection.tag && state.rawTags.some((tag) => tag.name === selection.tag)) {
+        state.tag = selection.tag;
+        state._tag = selection.tag;
+        applied = true;
+      }
+      if (selection.route && state.routeItems?.[selection.route]) {
+        state.routeId = selection.route;
+        applied = true;
+        const inferredTag = findTagByRoute(selection.route);
+        if (inferredTag) {
+          state.tag = inferredTag;
+          state._tag = inferredTag;
+        }
+      }
+      return applied;
+    }
+
     async function loadInitial() {
       state.initializing = true;
       try {
@@ -70,6 +138,30 @@ const app = createApp({
             acc[r.id] = r;
             return acc;
           }, {});
+        state.enableBriefMode = data.enable_brief_mode || false;
+        state.version = data.version || "";
+        state.swaggerUrl = data.swagger_url || null
+
+        const querySelection = readQuerySelection();
+        const restoredFromQuery = applySelectionFromQuery(querySelection);
+        if (restoredFromQuery) {
+          syncSelectionToUrl();
+          onGenerate();
+          return;
+        }
+
+        switch (data.initial_page_policy) {
+          case "full":
+            onGenerate()
+            return
+          case "empty":
+            return
+          case "first":
+            state.tag = state.rawTags.length > 0 ? state.rawTags[0].name : null;
+            state._tag = state.tag;
+            onGenerate();
+            return
+        }
 
         // default route options placeholder
       } catch (e) {
@@ -79,18 +171,31 @@ const app = createApp({
       }
     }
 
+    async function onFocusChange(val) {
+      if (val) {
+        await onGenerate(true); // target could be out of view when switchingfrom big to small
+      } else {
+        await onGenerate(false);
+        setTimeout(() => {
+          const ele = $(`[data-name='${schemaCodeName.value}'] polygon`);
+          ele.dblclick();
+        }, 1);
+      }
+    }
+
     async function onGenerate(resetZoom = true) {
+      const schema_name = state.focus ? schemaCodeName.value : null;
       state.generating = true;
       try {
         const payload = {
           tags: state.tag ? [state.tag] : null,
-          schema_name: state.schemaId || null,
+          schema_name: schema_name || null,
           route_name: state.routeId || null,
           show_fields: state.showFields,
           brief: state.brief,
           hide_primitive_route: state.hidePrimitiveRoute,
+          show_module: state.showModule,
         };
-
         const res = await fetch("dot", {
           method: "POST",
           headers: { "Content-Type": "application/json" },
@@ -99,29 +204,31 @@ const app = createApp({
         const dotText = await res.text();
 
         // create graph instance once
-        const graphUI = new GraphUI("#graph", {
-          onSchemaShiftClick: (id) => {
-            if (state.rawSchemas.has(id)) {
-              schemaFieldFilterSchema.value = id;
-              showSchemaFieldFilter.value = true;
-            }
-          },
-          onSchemaClick: (id) => {
-            if (state.rawSchemas.has(id)) {
-              schemaCodeName.value = id;
-              state.detailDrawer = true;
-            }
-            if (id in state.routeItems) {
-              routeCodeId.value = id;
-              showRouteDetail.value = true;
-            }
-          },
-          resetCb: () => {
-            state.detailDrawer = false;
-            showRouteDetail.value = false;
-          }
-        });
-
+        if (!graphUI) {
+          graphUI = new GraphUI("#graph", {
+            onSchemaShiftClick: (id) => {
+              if (state.rawSchemas.has(id)) {
+                resetDetailPanels();
+                schemaFieldFilterSchema.value = id;
+                showSchemaFieldFilter.value = true;
+              }
+            },
+            onSchemaClick: (id) => {
+              resetDetailPanels();
+              if (state.rawSchemas.has(id)) {
+                schemaCodeName.value = id;
+                state.detailDrawer = true;
+              }
+              if (id in state.routeItems) {
+                routeCodeId.value = id;
+                showRouteDetail.value = true;
+              }
+            },
+            resetCb: () => {
+              resetDetailPanels();
+            },
+          });
+        }
         await graphUI.render(dotText, resetZoom);
       } catch (e) {
         console.error("Generate failed", e);
@@ -192,23 +299,39 @@ const app = createApp({
       showSchemaFieldFilter.value = true;
     }
 
+    function resetDetailPanels() {
+      state.detailDrawer = false;
+      showRouteDetail.value = false;
+      schemaCodeName.value = "";
+    }
+
     async function onReset() {
       state.tag = null;
+      state._tag = null;
       state.routeId = "";
       state.schemaId = null;
       // state.showFields = "object";
-      state.brief = false;
+      state.focus = false;
+      schemaCodeName.value = "";
       onGenerate();
+      syncSelectionToUrl();
     }
 
     function toggleTag(tagName, expanded = null) {
       if (expanded === true) {
+        state._tag = tagName;
         state.tag = tagName;
         state.routeId = "";
+        state.focus = false;
+        schemaCodeName.value = "";
         onGenerate();
+      } else {
+        state._tag = null;
       }
+
       state.detailDrawer = false;
       showRouteDetail.value = false;
+      syncSelectionToUrl();
     }
 
     function selectRoute(routeId) {
@@ -219,7 +342,15 @@ const app = createApp({
       }
       state.detailDrawer = false;
       showRouteDetail.value = false;
+      state.focus = false;
+      schemaCodeName.value = "";
       onGenerate();
+      syncSelectionToUrl();
+    }
+
+    function toggleShowModule(val) {
+      state.showModule = val;
+      onGenerate()
     }
 
     function toggleShowField(field) {
@@ -237,8 +368,34 @@ const app = createApp({
       onGenerate(false);
     }
 
+    function startDragDrawer(e) {
+      const startX = e.clientX;
+      const startWidth = state.drawerWidth;
+
+      function onMouseMove(moveEvent) {
+        const deltaX = startX - moveEvent.clientX;
+        const newWidth = Math.max(300, Math.min(800, startWidth + deltaX));
+        state.drawerWidth = newWidth;
+      }
+
+      function onMouseUp() {
+        document.removeEventListener("mousemove", onMouseMove);
+        document.removeEventListener("mouseup", onMouseUp);
+        document.body.style.cursor = "";
+        document.body.style.userSelect = "";
+      }
+
+      document.addEventListener("mousemove", onMouseMove);
+      document.addEventListener("mouseup", onMouseUp);
+      document.body.style.cursor = "col-resize";
+      document.body.style.userSelect = "none";
+      e.preventDefault();
+    }
+
     onMounted(async () => {
+      document.body.classList.remove("app-loading")
       await loadInitial();
+      // Reveal app content only after initial JS/data is ready
     });
 
     return {
@@ -272,6 +429,9 @@ const app = createApp({
       showRenderGraph,
       renderCoreData,
       toggleShowField,
+      startDragDrawer,
+      onFocusChange,
+      toggleShowModule
     };
   },
 });
